pub struct MatrixAssignment {
pub task_id: String,
pub attempt_id: String,
pub worker_id: String,
pub phase: MatrixPhase,
pub generation: Option<String>,
}Expand description
Runtime-created assignment identity. Workers never choose these identifiers.
Fields
task_id: Stringattempt_id: Stringworker_id: Stringphase: MatrixPhasegeneration: Option<String>Trait Implementations
Sourceimpl Clone for MatrixAssignment
impl Clone for MatrixAssignment
Sourceimpl Debug for MatrixAssignment
impl Debug for MatrixAssignment
Sourceimpl<'de> Deserialize<'de> for MatrixAssignment
impl<'de> Deserialize<'de> for MatrixAssignment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatrixAssignment
Sourceimpl JsonSchema for MatrixAssignment
impl JsonSchema for MatrixAssignment
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatrixAssignment
impl PartialEq for MatrixAssignment
Sourceimpl Serialize for MatrixAssignment
impl Serialize for MatrixAssignment
impl StructuralPartialEq for MatrixAssignment