pub struct MatrixAttempt {
pub id: String,
pub worker_id: String,
pub phase: MatrixPhase,
pub generation: Option<String>,
pub launch_requested: bool,
pub outcome: Option<MatrixOutcome>,
pub cleanup_confirmed: bool,
pub evidence: Vec<MatrixCommandEvidence>,
}Fields
id: Stringworker_id: Stringphase: MatrixPhasegeneration: Option<String>launch_requested: booloutcome: Option<MatrixOutcome>cleanup_confirmed: boolevidence: Vec<MatrixCommandEvidence>Trait Implementations
Sourceimpl Clone for MatrixAttempt
impl Clone for MatrixAttempt
Sourceimpl Debug for MatrixAttempt
impl Debug for MatrixAttempt
Sourceimpl<'de> Deserialize<'de> for MatrixAttempt
impl<'de> Deserialize<'de> for MatrixAttempt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatrixAttempt
Sourceimpl JsonSchema for MatrixAttempt
impl JsonSchema for MatrixAttempt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatrixAttempt
impl PartialEq for MatrixAttempt
Sourceimpl Serialize for MatrixAttempt
impl Serialize for MatrixAttempt
impl StructuralPartialEq for MatrixAttempt