pub struct MatrixCommandEvidence {
pub command: String,
pub attempt_id: String,
pub worker_id: String,
pub generation: String,
pub event_id: String,
pub exit_code: Option<i32>,
pub cancelled: bool,
}Fields
command: Stringattempt_id: Stringworker_id: Stringgeneration: Stringevent_id: Stringexit_code: Option<i32>cancelled: boolTrait Implementations
Sourceimpl Clone for MatrixCommandEvidence
impl Clone for MatrixCommandEvidence
Sourceimpl Debug for MatrixCommandEvidence
impl Debug for MatrixCommandEvidence
Sourceimpl<'de> Deserialize<'de> for MatrixCommandEvidence
impl<'de> Deserialize<'de> for MatrixCommandEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatrixCommandEvidence
Sourceimpl JsonSchema for MatrixCommandEvidence
impl JsonSchema for MatrixCommandEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatrixCommandEvidence
impl PartialEq for MatrixCommandEvidence
Sourceimpl Serialize for MatrixCommandEvidence
impl Serialize for MatrixCommandEvidence
impl StructuralPartialEq for MatrixCommandEvidence