pub struct MatrixSnapshot {
pub spec: MatrixSpec,
pub lifecycle: MatrixLifecycle,
pub tasks: Vec<MatrixTaskState>,
pub generation: Option<String>,
pub revision: u64,
}Expand description
A complete checkpoint carried in the canonical event log; derived views replay it.
Fields
spec: MatrixSpeclifecycle: MatrixLifecycletasks: Vec<MatrixTaskState>generation: Option<String>revision: u64Trait Implementations
Sourceimpl Clone for MatrixSnapshot
impl Clone for MatrixSnapshot
Sourceimpl Debug for MatrixSnapshot
impl Debug for MatrixSnapshot
Sourceimpl<'de> Deserialize<'de> for MatrixSnapshot
impl<'de> Deserialize<'de> for MatrixSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatrixSnapshot
Sourceimpl JsonSchema for MatrixSnapshot
impl JsonSchema for MatrixSnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatrixSnapshot
impl PartialEq for MatrixSnapshot
Sourceimpl Serialize for MatrixSnapshot
impl Serialize for MatrixSnapshot
impl StructuralPartialEq for MatrixSnapshot