pub struct MatrixSpec {
pub id: String,
pub tasks: Vec<MatrixTaskSpec>,
pub resources: BTreeMap<String, u32>,
}Fields
id: Stringtasks: Vec<MatrixTaskSpec>resources: BTreeMap<String, u32>Trait Implementations
Sourceimpl Clone for MatrixSpec
impl Clone for MatrixSpec
Sourceimpl Debug for MatrixSpec
impl Debug for MatrixSpec
Sourceimpl<'de> Deserialize<'de> for MatrixSpec
impl<'de> Deserialize<'de> for MatrixSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatrixSpec
Sourceimpl JsonSchema for MatrixSpec
impl JsonSchema for MatrixSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatrixSpec
impl PartialEq for MatrixSpec
Sourceimpl Serialize for MatrixSpec
impl Serialize for MatrixSpec
impl StructuralPartialEq for MatrixSpec