pub struct MatrixTaskSpec {
pub id: String,
pub instructions: String,
pub dependencies: Vec<String>,
pub workspace: String,
pub access: WorkspaceAccess,
pub checks: Vec<String>,
pub resources: BTreeMap<String, u32>,
pub timeout_secs: u64,
pub replay_safe: bool,
pub inputs: Vec<String>,
}Fields
id: Stringinstructions: Stringdependencies: Vec<String>workspace: Stringaccess: WorkspaceAccesschecks: Vec<String>resources: BTreeMap<String, u32>timeout_secs: u64replay_safe: boolinputs: Vec<String>Trait Implementations
Sourceimpl Clone for MatrixTaskSpec
impl Clone for MatrixTaskSpec
Sourceimpl Debug for MatrixTaskSpec
impl Debug for MatrixTaskSpec
Sourceimpl<'de> Deserialize<'de> for MatrixTaskSpec
impl<'de> Deserialize<'de> for MatrixTaskSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatrixTaskSpec
Sourceimpl JsonSchema for MatrixTaskSpec
impl JsonSchema for MatrixTaskSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatrixTaskSpec
impl PartialEq for MatrixTaskSpec
Sourceimpl Serialize for MatrixTaskSpec
impl Serialize for MatrixTaskSpec
impl StructuralPartialEq for MatrixTaskSpec