pub struct MatrixTaskState {
pub id: String,
pub status: MatrixTaskStatus,
pub attempts: Vec<MatrixAttempt>,
pub automatic_retries: u8,
}Fields
id: Stringstatus: MatrixTaskStatusattempts: Vec<MatrixAttempt>automatic_retries: u8Trait Implementations
Sourceimpl Clone for MatrixTaskState
impl Clone for MatrixTaskState
Sourceimpl Debug for MatrixTaskState
impl Debug for MatrixTaskState
Sourceimpl<'de> Deserialize<'de> for MatrixTaskState
impl<'de> Deserialize<'de> for MatrixTaskState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatrixTaskState
Sourceimpl JsonSchema for MatrixTaskState
impl JsonSchema for MatrixTaskState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatrixTaskState
impl PartialEq for MatrixTaskState
Sourceimpl Serialize for MatrixTaskState
impl Serialize for MatrixTaskState
impl StructuralPartialEq for MatrixTaskState