pub struct DecisionItem {
pub summary: String,
pub rationale: String,
pub alternatives: Vec<String>,
pub evidence_ids: Vec<String>,
}Expand description
A consequential choice and the agent’s reported public rationale.
Fields
summary: Stringrationale: Stringalternatives: Vec<String>evidence_ids: Vec<String>Trait Implementations
Sourceimpl Clone for DecisionItem
impl Clone for DecisionItem
Sourceimpl Debug for DecisionItem
impl Debug for DecisionItem
Sourceimpl<'de> Deserialize<'de> for DecisionItem
impl<'de> Deserialize<'de> for DecisionItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DecisionItem
Sourceimpl JsonSchema for DecisionItem
impl JsonSchema for DecisionItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionItem
impl PartialEq for DecisionItem
Sourceimpl Serialize for DecisionItem
impl Serialize for DecisionItem
impl StructuralPartialEq for DecisionItem