pub struct ExecutionContext {
pub task_id: String,
pub turn_id: String,
pub actor_id: String,
pub parent_actor_id: Option<String>,
pub origin: InputOrigin,
pub timestamp: String,
pub goal: Option<String>,
}Expand description
Optional recorded execution ancestry. Absent fields are historical gaps.
Fields
task_id: Stringturn_id: Stringactor_id: Stringparent_actor_id: Option<String>origin: InputOrigintimestamp: Stringgoal: Option<String>Trait Implementations
Sourceimpl Clone for ExecutionContext
impl Clone for ExecutionContext
Sourceimpl Debug for ExecutionContext
impl Debug for ExecutionContext
Sourceimpl<'de> Deserialize<'de> for ExecutionContext
impl<'de> Deserialize<'de> for ExecutionContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionContext
Sourceimpl JsonSchema for ExecutionContext
impl JsonSchema for ExecutionContext
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionContext
impl PartialEq for ExecutionContext
Sourceimpl Serialize for ExecutionContext
impl Serialize for ExecutionContext
impl StructuralPartialEq for ExecutionContext