pub struct ItemContext {
pub task_id: String,
pub turn_id: String,
pub actor_id: String,
pub parent_actor_id: Option<String>,
pub timestamp: String,
pub activity: Option<CommandActivity>,
}Expand description
Item identity, timing, and command semantics for explanation consumers.
Fields
task_id: Stringturn_id: Stringactor_id: Stringparent_actor_id: Option<String>timestamp: Stringactivity: Option<CommandActivity>Trait Implementations
Sourceimpl Clone for ItemContext
impl Clone for ItemContext
Sourceimpl Debug for ItemContext
impl Debug for ItemContext
Sourceimpl<'de> Deserialize<'de> for ItemContext
impl<'de> Deserialize<'de> for ItemContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ItemContext
Sourceimpl JsonSchema for ItemContext
impl JsonSchema for ItemContext
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ItemContext
impl PartialEq for ItemContext
Sourceimpl Serialize for ItemContext
impl Serialize for ItemContext
impl StructuralPartialEq for ItemContext