OtelEmitter

Struct OtelEmitter 

pub struct OtelEmitter<T: Tracer> { /* private fields */ }
Emits ThreadEvents as OpenTelemetry spans and span events.

Each ThreadEvent is recorded as an OTel span with attributes derived from the event payload. Harness events are attached as span events with their own attributes (event kind, message, path, etc.).

Usage

use vtcode_exec_events::OtelEmitter;
use opentelemetry::trace::TracerProvider;

let provider = TracerProvider::default();
let tracer = provider.tracer("vtcode");
let mut emitter = OtelEmitter::new(tracer);

Implementations

Source

impl<T: Tracer> OtelEmitter<T>

pub fn new(tracer: T) -> Self